@@ -6,12 +6,10 @@ from pypop7.optimizers.eda.eda import EDA
 class UMDA(EDA):
     """Univariate Marginal Distribution Algorithm for normal models (UMDA).
 
-    .. note:: `UMDA` learns only the diagonal elements of covariance matrix of the Gaussian sampling
-       distribution, resulting in *linear* time complexity for each generation. Therefore, it can be
-       seen as a simple *baseline* for large-scale black-box optimization (LSBBO).
-
-       To obtain satisfactory performance for LSBBO, the number of offspring may need to be carefully
-       tuned.
+    .. note:: `UMDA` learns only the *diagonal* elements of covariance matrix of the Gaussian sampling
+       distribution, resulting in a *linear* time complexity w.r.t. each sampling. Therefore, it can be
+       seen as a *baseline* for large-scale black-box optimization (LSBBO). To obtain satisfactory
+       performance for LSBBO, the number of offspring may need to be carefully tuned.
 
     Parameters
     ----------
@@ -25,20 +23,11 @@ class UMDA(EDA):
               optimizer options with the following common settings (`keys`):
                 * 'max_function_evaluations' - maximum of function evaluations (`int`, default: `np.Inf`),
                 * 'max_runtime'              - maximal runtime (`float`, default: `np.Inf`),
-                * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`),
-                * 'record_fitness'           - flag to record fitness list to output results (`bool`, default: `False`),
-                * 'record_fitness_frequency' - function evaluations frequency of recording (`int`, default: `1000`),
-
-                  * if `record_fitness` is set to `False`, it will be ignored,
-                  * if `record_fitness` is set to `True` and it is set to 1, all fitness generated during optimization
-                    will be saved into output results.
-
-                * 'verbose'                  - flag to print verbose info during optimization (`bool`, default: `True`),
-                * 'verbose_frequency'        - frequency of printing verbose info (`int`, default: `10`);
-              and with two particular settings (`keys`):
+                * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`);
+              and with the following particular settings (`keys`):
                 * 'n_individuals' - number of offspring, offspring population size (`int`, default: `200`),
                 * 'n_parents'     - number of parents, parental population size (`int`, default:
-                  `int(self.n_individuals / 2)`).
+                  `int(self.n_individuals/2)`).
 
     Examples
     --------
@@ -61,8 +50,6 @@ class UMDA(EDA):
        >>> results = umda.optimize()  # run the optimization process
        >>> # return the number of function evaluations and best-so-far fitness
        >>> print(f"UMDA: {results['n_function_evaluations']}, {results['best_so_far_y']}")
-         * Generation 10: best_so_far_y 2.93234e-02, min(y) 3.38630e-01 & Evaluations 2200
-         * Generation 20: best_so_far_y 2.93234e-02, min(y) 4.83760e-01 & Evaluations 4200
        UMDA: 5000, 0.029323401402499186
 
     For its correctness checking, refer to `this code-based repeatability report
@@ -123,17 +110,19 @@ class UMDA(EDA):
         for i in range(self.n_individuals):
             if self._check_terminations():
                 break
-            x[i] = mean + sigmas * self.rng_optimization.standard_normal(size=(self.ndim_problem,))
+            x[i] = mean + sigmas*self.rng_optimization.standard_normal(size=(self.ndim_problem,))
             y[i] = self._evaluate_fitness(x[i], args)
         return x, y
 
     def optimize(self, fitness_function=None, args=None):
         fitness = EDA.optimize(self, fitness_function)
         x, y = self.initialize(args)
-        fitness.extend(y)
+        if self.saving_fitness:
+            fitness.extend(y)
+        self._print_verbose_info(y)
         while True:
             x, y = self.iterate(x, y, args)
-            if self.record_fitness:
+            if self.saving_fitness:
                 fitness.extend(y)
             if self._check_terminations():
                 break
