@@ -1,4 +1,5 @@
 import numpy as np
+from scipy.stats import cauchy
 
 from pypop7.optimizers.ep.cep import CEP
 
@@ -6,13 +7,10 @@ from pypop7.optimizers.ep.cep import CEP
 class FEP(CEP):
     """Fast Evolutionary Programming with self-adaptive mutation (FEP).
 
-    .. note:: `FEP` was proposed by Yao, recipient of both `Evolutionary Computation Pioneer Award
+    .. note:: `FEP` was proposed mainly by Yao in 1999, recipient of both `Evolutionary Computation Pioneer Award
        2013 <https://tinyurl.com/456as566>`_ and `IEEE Frank Rosenblatt Award 2020
-       <https://tinyurl.com/yj28zxfa>`_ and others, where the classical Gaussian sampling distribution
-       is replaced by the Heavy-tailed Cachy distribution for better exploration on hard multi-modal problems.
-
-       To obtain satisfactory performance for large-scale black-box optimization, the number of
-       offspring may need to be carefully tuned.
+       <https://tinyurl.com/yj28zxfa>`_, where the classical Gaussian sampling distribution is replaced by the
+       heavy-tailed Cachy distribution for better exploration on multi-modal black-box problems.
 
     Parameters
     ----------
@@ -26,24 +24,15 @@ class FEP(CEP):
               optimizer options with the following common settings (`keys`):
                 * 'max_function_evaluations' - maximum of function evaluations (`int`, default: `np.Inf`),
                 * 'max_runtime'              - maximal runtime (`float`, default: `np.Inf`),
-                * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`),
-                * 'record_fitness'           - flag to record fitness list to output results (`bool`, default: `False`),
-                * 'record_fitness_frequency' - function evaluations frequency of recording (`int`, default: `1000`),
-
-                  * if `record_fitness` is set to `False`, it will be ignored,
-                  * if `record_fitness` is set to `True` and it is set to 1, all fitness generated during optimization
-                    will be saved into output results.
-
-                * 'verbose'                  - flag to print verbose info during optimization (`bool`, default: `True`),
-                * 'verbose_frequency'        - frequency of printing verbose info (`int`, default: `10`);
-              and with five particular settings (`keys`):
-                * 'n_individuals'  - number of offspring, offspring population size (`int`),
-                * 'sigma'          - initial global step-size (σ), mutation strength (`float`),
+                * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`);
+              and with the following particular settings (`keys`):
+                * 'sigma'          - initial global step-size, mutation strength (`float`),
+                * 'n_individuals'  - number of offspring, offspring population size (`int`, default: `100`),
                 * 'q'              - number of opponents for pairwise comparisons (`int`, default: `10`),
-                * 'tau'            - learning rate of individual step-sizes (`float`, default:
-                  `1.0 / np.sqrt(2.0*np.sqrt(self.ndim_problem))`),
-                * 'tau_apostrophe' - learning rate of individual step-sizes (`float`, default:
-                  `1.0 / np.sqrt(2.0*self.ndim_problem)`.
+                * 'tau'            - learning rate of individual step-sizes self-adaptation (`float`, default:
+                  `1.0/np.sqrt(2.0*np.sqrt(self.ndim_problem))`),
+                * 'tau_apostrophe' - learning rate of individual step-sizes self-adaptation (`float`, default:
+                  `1.0/np.sqrt(2.0*self.ndim_problem)`.
 
     Examples
     --------
@@ -67,11 +56,7 @@ class FEP(CEP):
        >>> results = fep.optimize()  # run the optimization process
        >>> # return the number of function evaluations and best-so-far fitness
        >>> print(f"FEP: {results['n_function_evaluations']}, {results['best_so_far_y']}")
-         * Generation 10: best_so_far_y 6.55719e-02, min(y) 6.55719e-02 & Evaluations 1100
-         * Generation 20: best_so_far_y 5.94376e-02, min(y) 5.94376e-02 & Evaluations 2100
-         * Generation 30: best_so_far_y 2.17722e-02, min(y) 2.17722e-02 & Evaluations 3100
-         * Generation 40: best_so_far_y 5.81916e-03, min(y) 5.81916e-03 & Evaluations 4100
-       FEP: 5000, 0.004682685065944951
+       FEP: 5000, 0.030161392945621774
 
     For its correctness checking, refer to `this code-based repeatability report
     <https://tinyurl.com/bdh7epah>`_ for more details.
@@ -85,9 +70,9 @@ class FEP(CEP):
     q              : `int`
                      number of opponents for pairwise comparisons。
     tau            : `float`
-                     learning rate of individual step-sizes.
+                     learning rate of individual step-sizes self-adaptation.
     tau_apostrophe : `float`
-                     learning rate of individual step-sizes.
+                     learning rate of individual step-sizes self-adaptation.
 
     References
     ----------
@@ -104,24 +89,24 @@ class FEP(CEP):
     def __init__(self, problem, options):
         CEP.__init__(self, problem, options)
 
-    def iterate(self, x=None, sigmas=None, y=None,
-                offspring_x=None, offspring_sigmas=None, offspring_y=None):
+    def iterate(self, x=None, sigmas=None, y=None, xx=None, ss=None, yy=None, args=None):
         for i in range(self.n_individuals):
             if self._check_terminations():
-                return x, sigmas, y, offspring_x, offspring_sigmas, offspring_y
+                return x, sigmas, y, xx, ss, yy
             base_normal = self.rng_optimization.standard_normal()
             for j in range(self.ndim_problem):
-                offspring_sigmas[i][j] = sigmas[i][j]*np.exp(
+                ss[i][j] = sigmas[i][j]*np.exp(
                     self.tau_apostrophe*base_normal +
                     self.tau*self.rng_optimization.standard_normal())
-                offspring_x[i][j] = x[i][j] + offspring_sigmas[i][j]*self.rng_optimization.standard_cauchy()
-            offspring_y[i] = self._evaluate_fitness(offspring_x[i])
-        new_x = np.vstack((offspring_x, x))
-        new_sigmas = np.vstack((offspring_sigmas, sigmas))
-        new_y = np.hstack((offspring_y, y))
+                xx[i][j] = x[i][j] + ss[i][j]*cauchy.rvs(
+                    loc=0.0, scale=1.0, random_state=self.rng_optimization)
+            yy[i] = self._evaluate_fitness(xx[i], args)
+        new_x = np.vstack((xx, x))
+        new_sigmas = np.vstack((ss, sigmas))
+        new_y = np.hstack((yy, y))
         n_win = np.zeros((2*self.n_individuals,))  # number of win
         for i in range(2*self.n_individuals):
-            for j in self.rng_optimization.integers(2*self.n_individuals, size=self.q):
+            for j in self.rng_optimization.choice(2*self.n_individuals, size=self.q, replace=False):
                 if new_y[i] <= new_y[j]:
                     n_win[i] += 1
         order = np.argsort(-n_win)
@@ -129,4 +114,5 @@ class FEP(CEP):
             x[i] = new_x[order[i]]
             sigmas[i] = new_sigmas[order[i]]
             y[i] = new_y[order[i]]
-        return x, sigmas, y, offspring_x, offspring_sigmas, offspring_y
+        self._n_generations += 1
+        return x, sigmas, y, xx, ss, yy
