@@ -12,7 +12,7 @@ class MAES(ES):
        the underlying working principles (e.g., **invariance** and **unbias**) of `CMA-ES`, which is often thought to
        be rather complex for newcomers.
 
-       It is **highly recommended** to first attempt other more advanced ES variants (e.g., `LM-CMA`, `LM-MA-ES`) for
+       It is **highly recommended** to first attempt other more advanced ES variants (e.g., `LMCMA`, `LMMAES`) for
        large-scale black-box optimization, since `MAES` has a *cubic* time complexity w.r.t. each sampling. Note that
        another improved version called `FMAES` provides a *relatively more efficient* implementation for `MAES` with
        *quadratic* time complexity w.r.t. each sampling.
