@@ -1,3 +1,8 @@
+"""This code only tests whether the corresponding optimizer could run or not.
+  In other words, it *cannot* validate the correctness regarding its working procedure.
+  For the correctness validation of programming, refer to the following link:
+    https://github.com/Evolutionary-Intelligence/pypop/wiki/Correctness-Validation-of-Optimizers.md
+"""
 import unittest
 import time
 
