@@ -10,7 +10,7 @@ class PRS(RS):
         has been successfully applied in several *relatively low-dimensional* problems (particularly
         `hyper-parameter optimization <https://www.jmlr.org/papers/v13/bergstra12a.html>`_), it generally
         suffers from the famous **curse of dimensionality** for large-scale black-box optimization (LSBBO),
-        since its lack of *adaptation*, a highly desirable property for sophisticated search algorithms.
+        owing to its lack of *adaptation*, a highly desirable property for sophisticated search algorithms.
         Therefore, it is **highly recommended** to first attempt other more advanced (e.g. population-based)
         methods for LSBBO.
 
@@ -28,7 +28,7 @@ class PRS(RS):
     options : dict
               optimizer options with the following common settings (`keys`):
                 * 'max_function_evaluations' - maximum of function evaluations (`int`, default: `np.Inf`),
-                * 'max_runtime'              - maximal runtime (`float`, default: `np.Inf`),
+                * 'max_runtime'              - maximal runtime to be allowed (`float`, default: `np.Inf`),
                 * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`).
 
     Examples
@@ -65,6 +65,11 @@ class PRS(RS):
     Journal of Machine Learning Research, 13(2).
     https://www.jmlr.org/papers/v13/bergstra12a.html
 
+    Schmidhuber, J., Hochreiter, S. and Bengio, Y., 2001.
+    Evaluating benchmark problems by random guessing.
+    A Field Guide to Dynamical Recurrent Networks, pp.231-235.
+    https://ml.jku.at/publications/older/ch9.pdf
+
     Brooks, S.H., 1958.
     A discussion of random methods for seeking maxima.
     Operations Research, 6(2), pp.244-251.
