@@ -12,7 +12,7 @@ class RS(Optimizer):
 
     .. note:: `"The topic of local search was reinvigorated in the early 1990s by surprisingly good results
        for large ... problems ... and by the incorporation of randomness, multiple simultaneous searches,
-       and other improvements." ---[Russell&Norvig, 2022] <http://aima.cs.berkeley.edu/global-index.html>`_
+       and other improvements."---[Russell&Norvig, 2022] <http://aima.cs.berkeley.edu/global-index.html>`_
 
     Parameters
     ----------
@@ -25,7 +25,7 @@ class RS(Optimizer):
     options : dict
               optimizer options with the following common settings (`keys`):
                 * 'max_function_evaluations' - maximum of function evaluations (`int`, default: `np.Inf`),
-                * 'max_runtime'              - maximal runtime (`float`, default: `np.Inf`),
+                * 'max_runtime'              - maximal runtime to be allowed (`float`, default: `np.Inf`),
                 * 'seed_rng'                 - seed for random number generation needed to be *explicitly* set (`int`);
               and with the following particular setting (`key`):
                 * 'x' - initial (starting) point (`array_like`).
@@ -41,7 +41,7 @@ class RS(Optimizer):
     References
     ----------
     Gao, K. and Sener, O., 2022, June.
-    Generalizing Gaussian Smoothing for Random Search.
+    Generalizing Gaussian smoothing for random search.
     In International Conference on Machine Learning (pp. 7077-7101). PMLR.
     https://proceedings.mlr.press/v162/gao22f.html
 
@@ -55,6 +55,11 @@ class RS(Optimizer):
     SIAM Journal on Optimization, 14(3), pp.708-731.
     https://epubs.siam.org/doi/abs/10.1137/S105262340240063X
 
+    Schmidhuber, J., Hochreiter, S. and Bengio, Y., 2001.
+    Evaluating benchmark problems by random guessing.
+    A Field Guide to Dynamical Recurrent Networks, pp.231-235.
+    https://ml.jku.at/publications/older/ch9.pdf
+
     Rastrigin, L.A., 1986.
     Random search as a method for optimization and adaptation.
     In Stochastic Optimization.
